@@ -1,7 +1,7 @@
 package Bencher::Scenario::Interpreters;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,11 +30,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::Interpreters
+Bencher::Scenario::Interpreters - Benchmark startup time of various interpreters
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Interpreters (from Perl distribution Bencher-Scenario-Interpreters), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::Interpreters (from Perl distribution Bencher-Scenario-Interpreters), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -92,19 +92,19 @@ Command line:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m Interpreters >>):
 
- +-----+--------+---------+--------+---------+---------+
- | seq | name   | rate    | time   | errors  | samples |
- +-----+--------+---------+--------+---------+---------+
- | 4   | nodejs | 36      | 27.7ms | 6.9e-05 | 20      |
- | 2   | ruby   | 75      | 13ms   | 9.1e-05 | 21      |
- | 3   | python | 82.9    | 12.1ms | 1.7e-05 | 20      |
- | 1   | bash   | 1.5e+02 | 6.6ms  | 2.9e-05 | 22      |
- | 0   | perl   | 2e+02   | 5.1ms  | 5e-05   | 20      |
- +-----+--------+---------+--------+---------+---------+
+ +-------------+-----------+-----------+------------+---------+---------+
+ | participant | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-------------+-----------+-----------+------------+---------+---------+
+ | nodejs      |        50 |      20   |        1   | 6.1e-05 |      20 |
+ | ruby        |       110 |       9.1 |        2.2 | 6.3e-05 |      20 |
+ | python      |       110 |       8.8 |        2.3 | 3.2e-05 |      20 |
+ | perl        |       390 |       2.5 |        7.9 | 6.7e-06 |      20 |
+ | bash        |       400 |       2.5 |        8   | 1.7e-05 |      20 |
+ +-------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
